@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Rope::Object;
 my (%META, %PRO);
@@ -213,6 +213,18 @@ BEGIN {
 				}
 			}
 		},
+		locked => sub {
+			my ($caller) = shift;
+			return sub {
+				my ($self, $locked) = @_;
+				if (ref $self) {
+					$self->{locked} = $locked;
+					return;
+				} else {
+					$META{$caller}{locked} = 1;
+				}
+			};
+		},
 		new => sub {
 			my ($caller) = shift;
 			return sub {
@@ -276,7 +288,7 @@ sub import {
 	$PRO{keyword}($caller, $_, $PRO{$_}($caller))
 		for $options->{import} 
 			? @{$options->{import}} 
-			: qw/function property properties prototyped extends with requires new/;
+			: qw/function property properties prototyped extends with requires locked new/;
 }
 
 sub new {
@@ -304,6 +316,7 @@ sub new {
 		eval $c;
 	}
 
+	$META{$name}{locked} = $meta->{locked} if (defined $meta->{locked});
 	$PRO{requires}($name)(@{$meta->{requires}}) if ($meta->{requires});
 	$PRO{extends}($name)(@{$meta->{extends}}) if ($meta->{extends});
 	$PRO{with}($name)(@{$meta->{with}}) if ($meta->{with});
@@ -321,7 +334,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
@@ -457,7 +470,14 @@ Extends the current object definition with a new property that acts as a functio
 		my ($self, $param) = @_;
 		...
 	};
-	
+
+NOTE: normal sub tradditional routines work and should be inherited also.	
+
+	sub three {
+		my ($self, $param) = @_;
+		...
+	}
+
 =head2 extends
 
 The extends keyword allows you to extend your current definition with another object, your objext will inherit all the properties of that extended object.
@@ -492,6 +512,26 @@ The requires keyword allows you to define properties which are required for eith
 		host => '...'
 	);
 
+=head2 locked
+
+The locked keyword can be used to lock your Object so that it can no longer be extended with new properties/keys.
+
+	package Locked;
+
+	use Rope;
+
+	property one => ( ... );
+
+	locked;
+
+	1;
+
+Once you have an object initialised you can toggle whether is locked by calling 'locked' with either a true or false value.
+
+	$obj->locked(1);
+
+	$obj->locked(0);
+
 =head1 METHODS
 
 =head2 new
@@ -525,7 +565,7 @@ Along with class definitions you can also generate object using Rope itself, the
 	$knot->{loops};
 	$with->loops;
 
-=head1 CLASS DEFINITION
+=head1 OBJECT CLASS DEFINITION
 
 	package Builder;
 
@@ -556,7 +596,7 @@ Along with class definitions you can also generate object using Rope itself, the
 	1;
 
 
-=head1 ROLE DEFINITION
+=head1 OBJECT ROLE DEFINITION
 
 	package Builder::Role;
 
