@@ -57,6 +57,11 @@ sub set_value {
 sub STORE {
         my ($self, $key, $value) = @_;
 
+	if ($key eq 'locked') {
+		$self->{locked} = $value;
+		return;
+	}
+
 	my $k = $self->{properties}->{$key};
 	if ($k) {
 		if ($k->{writeable}) {
